@@ -3,7 +3,7 @@ package ScriptX;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-03'; # DATE
 our $DIST = 'ScriptX'; # DIST
-our $VERSION = '0.000'; # VERSION
+our $VERSION = '0.000001'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -14,7 +14,10 @@ use Log::ger;
 our %Plugins;
 our %Handlers;
 
-my $Stash = {};
+my $Stash = {
+    plugins => \%Plugins,
+    handlers => \%Handlers,
+};
 
 sub run_event {
     my %args = @_;
@@ -311,7 +314,7 @@ ScriptX - A plugin-based script framework
 
 =head1 VERSION
 
-This document describes version 0.000 of ScriptX (from Perl distribution ScriptX), released on 2020-09-03.
+This document describes version 0.000001 of ScriptX (from Perl distribution ScriptX), released on 2020-09-03.
 
 =head1 SYNOPSIS
 
@@ -322,6 +325,8 @@ In your script:
 
 =head1 DESCRIPTION
 
+B<EXPERIMENTAL, EARLY RELEASE.>
+
 For now, see the included example scripts.
 
 =head2 Glossary
@@ -381,6 +386,10 @@ prefix (e.g. L<Exit|ScriptX::Exit>) and values are plugin instances.
 
 =head1 STASH KEYS
 
+=head2 event
+
+The name of current event.
+
 =head2 handlers
 
 Reference to the L<%Handlers> package variable, for convenience.
@@ -389,6 +398,14 @@ Reference to the L<%Handlers> package variable, for convenience.
 
 Reference to the L<%Plugins> package variable, for convenience.
 
+=head2 plugin_name
+
+Set for C<activate_plugin> event.
+
+=head2 plugin_args
+
+Set for C<activate_plugin> event.
+
 =head1 EVENT HANDLER RETURN STATUS CODES
 
 The following are known event handler return status codes. They roughly follow
